# Changelog

## 0.0.3

- Update api test to make ues of only current blocks because of litenodes block limits.
- Updated documentation to compile with sphinx correctly.

## 0.0.2

- Tried to finish all the misc branding stuff that I may have missed

## 0.0.1

- Inital version
